==> cobalt.rs-0.19.5.tar.gz: cobalt.rs-0.19.5/crates/engarde/CHANGELOG.md <==
# Change Log
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

<!-- next-header -->
## [Unreleased] - ReleaseDate

## [0.1.10] - 2024-07-05

## [0.1.9] - 2024-07-05

### Fixes

- Don't crash when escaping HTML with UTF-8 characters

### Compatibility

- MSRV is now 1.76

## [0.1.8] - 2024-04-15

## [0.1.7] - 2024-02-28

### Compatibility

- MSRV is now 1.73

## [0.1.6] - 2023-04-20

### Compatibility

- MSRV is now 1.64.0

## [0.1.5] - 2022-08-29

## [0.1.4] - 2022-08-29

## [0.1.3] - 2022-08-26

### Fixes

- Wrap code fences in `<pre><code>` instead of just `<pre>`

## [0.1.2] - 2022-08-24

## [0.1.1] - 2022-04-04

<!-- next-url -->
[Unreleased]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.10...HEAD
[0.1.10]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.9...engarde-v0.1.10
[0.1.9]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.8...engarde-v0.1.9
[0.1.8]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.7...engarde-v0.1.8
[0.1.7]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.6...engarde-v0.1.7
[0.1.6]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.5...engarde-v0.1.6
[0.1.5]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.4...engarde-v0.1.5
[0.1.4]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.3...engarde-v0.1.4
[0.1.3]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.2...engarde-v0.1.3
[0.1.2]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.1...engarde-v0.1.2
[0.1.1]: https://github.com/cobalt-org/cobalt.rs/compare/b805d1fcd105898446de9431582c38724fe5aa59...engarde-v0.1.1

==> cobalt.rs-0.19.7.tar.gz: cobalt.rs-0.19.7/crates/engarde/CHANGELOG.md <==
# Change Log
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

<!-- next-header -->
## [Unreleased] - ReleaseDate

## [0.1.12] - 2025-02-27

### Compatibility

- MSRV is now 1.85

## [0.1.11] - 2024-08-07

## [0.1.10] - 2024-07-05

## [0.1.9] - 2024-07-05

### Fixes

- Don't crash when escaping HTML with UTF-8 characters

### Compatibility

- MSRV is now 1.76

## [0.1.8] - 2024-04-15

## [0.1.7] - 2024-02-28

### Compatibility

- MSRV is now 1.73

## [0.1.6] - 2023-04-20

### Compatibility

- MSRV is now 1.64.0

## [0.1.5] - 2022-08-29

## [0.1.4] - 2022-08-29

## [0.1.3] - 2022-08-26

### Fixes

- Wrap code fences in `<pre><code>` instead of just `<pre>`

## [0.1.2] - 2022-08-24

## [0.1.1] - 2022-04-04

<!-- next-url -->
[Unreleased]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.12...HEAD
[0.1.12]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.11...engarde-v0.1.12
[0.1.11]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.10...engarde-v0.1.11
[0.1.10]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.9...engarde-v0.1.10
[0.1.9]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.8...engarde-v0.1.9
[0.1.8]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.7...engarde-v0.1.8
[0.1.7]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.6...engarde-v0.1.7
[0.1.6]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.5...engarde-v0.1.6
[0.1.5]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.4...engarde-v0.1.5
[0.1.4]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.3...engarde-v0.1.4
[0.1.3]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.2...engarde-v0.1.3
[0.1.2]: https://github.com/cobalt-org/cobalt.rs/compare/engarde-v0.1.1...engarde-v0.1.2
[0.1.1]: https://github.com/cobalt-org/cobalt.rs/compare/b805d1fcd105898446de9431582c38724fe5aa59...engarde-v0.1.1
